
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#if defined(ATK_DISABLE_SINGLE_INCLUDES) && !defined (__ATK_H_INSIDE__) && !defined (ATK_COMPILATION)
#error "Only <atk/atk.h> can be included directly."
#endif

#ifndef __ATK_ENUM_TYPES_H__
#define __ATK_ENUM_TYPES_H__

#include <atk/atkversion.h>
#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "atkcomponent.h" */
ATK_AVAILABLE_IN_ALL
GType atk_scroll_type_get_type (void);
#define ATK_TYPE_SCROLL_TYPE (atk_scroll_type_get_type())

/* enumerations from "atkhyperlink.h" */
ATK_AVAILABLE_IN_ALL
GType atk_hyperlink_state_flags_get_type (void);
#define ATK_TYPE_HYPERLINK_STATE_FLAGS (atk_hyperlink_state_flags_get_type())

/* enumerations from "atkobject.h" */
ATK_AVAILABLE_IN_ALL
GType atk_role_get_type (void);
#define ATK_TYPE_ROLE (atk_role_get_type())
ATK_AVAILABLE_IN_ALL
GType atk_layer_get_type (void);
#define ATK_TYPE_LAYER (atk_layer_get_type())

/* enumerations from "atkrelationtype.h" */
ATK_AVAILABLE_IN_ALL
GType atk_relation_type_get_type (void);
#define ATK_TYPE_RELATION_TYPE (atk_relation_type_get_type())

/* enumerations from "atkstate.h" */
ATK_AVAILABLE_IN_ALL
GType atk_state_type_get_type (void);
#define ATK_TYPE_STATE_TYPE (atk_state_type_get_type())

/* enumerations from "atktext.h" */
ATK_AVAILABLE_IN_ALL
GType atk_text_attribute_get_type (void);
#define ATK_TYPE_TEXT_ATTRIBUTE (atk_text_attribute_get_type())
ATK_AVAILABLE_IN_ALL
GType atk_text_boundary_get_type (void);
#define ATK_TYPE_TEXT_BOUNDARY (atk_text_boundary_get_type())
ATK_AVAILABLE_IN_ALL
GType atk_text_granularity_get_type (void);
#define ATK_TYPE_TEXT_GRANULARITY (atk_text_granularity_get_type())
ATK_AVAILABLE_IN_ALL
GType atk_text_clip_type_get_type (void);
#define ATK_TYPE_TEXT_CLIP_TYPE (atk_text_clip_type_get_type())

/* enumerations from "atkutil.h" */
ATK_AVAILABLE_IN_ALL
GType atk_key_event_type_get_type (void);
#define ATK_TYPE_KEY_EVENT_TYPE (atk_key_event_type_get_type())
ATK_AVAILABLE_IN_ALL
GType atk_coord_type_get_type (void);
#define ATK_TYPE_COORD_TYPE (atk_coord_type_get_type())

/* enumerations from "atkvalue.h" */
ATK_AVAILABLE_IN_ALL
GType atk_value_type_get_type (void);
#define ATK_TYPE_VALUE_TYPE (atk_value_type_get_type())
G_END_DECLS

#endif /* __ATK_ENUM_TYPES_H__ */

/* Generated data ends here */

